<?php
/**
 * The file that defines autoload class
 *
 * A simple autoloader that loads class files recursively starting in the directory
 * where this class resides.  Additional options can be provided to control the naming
 * convention of the class files.
 *
 * @link        https://themeisle.com
 * @copyright   Copyright (c) 2017, Bogdan Preda
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 *
 * @since       1.1.40
 * @package     bigbang
 */

/**
 * The Autoloader class.
 *
 * @since      1.1.40
 * @package    bigbang
 * @author     Themeisle <friends@themeisle.com>
 */
class bigbang_Autoloader {

	/**
	 * List of available classes to get for autoloading.
	 *
	 * @var array
	 */
	private $classes_to_load = array();

	/**
	 * bigbang_Autoloader constructor.
	 *
	 * Define the file paths.
	 */
	public function __construct() {
		$this->classes_to_load = array(
			'bigbang_Content_Import'                      => bigbang_PHP_INCLUDE . 'content-import',
			'bigbang_Import_Utilities'                    => bigbang_PHP_INCLUDE . 'content-import',
			'bigbang_Import_Zerif'                        => bigbang_PHP_INCLUDE . 'content-import',
			
			'bigbang_Plugin_Install_Helper'               => bigbang_PHP_INCLUDE . 'plugin-install',
			'bigbang_Bootstrap_Navwalker'                 => bigbang_PHP_INCLUDE . 'wp-bootstrap-navwalker',
			
			
		);
	}


	/**
	 * Autoload function for registration with spl_autoload_register
	 *
	 * @since   1.1.40
	 * @access  public
	 *
	 * @param   string $class_name The class name requested.
	 *
	 * @return mixed
	 */
	public function loader( $class_name ) {
		if ( ! array_key_exists( $class_name, $this->classes_to_load ) ) {
			return false;
		}

		$filename  = 'class-' . str_replace( '_', '-', strtolower( $class_name ) ) . '.php';
		$full_path = trailingslashit( $this->classes_to_load[ $class_name ] ) . $filename;
		if ( file_exists( $full_path ) ) {
			require $full_path;
		}

		return true;
	}
}
