<?php
/**
 * Customizer functionality for the About section.
 *
 * @package bigbang
 * @since bigbang 1.0
 */

$page_editor_path = trailingslashit( get_template_directory() ) . 'inc/customizer-page-editor/customizer-page-editor.php';
if ( file_exists( $page_editor_path ) ) {
	require_once( $page_editor_path );
}

/**
 * Hook controls for About section to Customizer.
 *
 * @since bigbang 1.0
 * @modified 1.1.49
 */


/**
 * Add selective refresh for about section controls.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 * @since 1.1.31
 * @access public
 */
function bigbang_register_about_partials( $wp_customize ) {
	// Abort if selective refresh is not available.
	if ( ! isset( $wp_customize->selective_refresh ) ) {
		return;
	}

	$wp_customize->selective_refresh->add_partial(
		'bigbang_page_editor', array(
			'selector'        => '.bigbang-about-content',
			'settings'        => 'bigbang_page_editor',
			'render_callback' => 'bigbang_about_content_callback',
		)
	);
}
add_action( 'customize_register', 'bigbang_register_about_partials' );


/**
 * Render callback for about image selective refresh.
 *
 * @since   1.1.25
 * @access  public
 */
function bigbang_about_image_callback() {
	$bigbang_feature_thumbnail = get_theme_mod( 'bigbang_feature_thumbnail' );
	if ( ! empty( $bigbang_feature_thumbnail ) ) { ?>
		<style class="bigbang-about-image-css">
			#about {
				background-image: url(<?php echo ! empty( $bigbang_feature_thumbnail ) ? esc_url( $bigbang_feature_thumbnail ) : ''; ?>) !important;
			}
		</style>
		<?php
	} else {
		?>
		<style class="bigbang-about-image-css">
			#about {
				background-image: none !important;
			}
		</style>
		<?php
	}
}

/**
 * Render callback for about section content selective refresh
 *
 * @since 1.1.31
 * @access public
 */
function bigbang_about_content_callback() {
	if ( have_posts() ) :
		while ( have_posts() ) :
			the_post();
			get_template_part( 'template-parts/content', 'frontpage' );
		endwhile;
	else : // I'm not sure it's possible to have no posts when this page is shown, but WTH
		get_template_part( 'template-parts/content', 'none' );
	endif;
}

/**
 * Page editor control active callback function
 *
 * @return bool
 */
function bigbang_is_static_page() {
	return 'page' === get_option( 'show_on_front' );
}


/**
 * Callback for About section content editor
 *
 * @return bool
 */
function bigbang_display_content_editor() {
	if ( 'page' === get_option( 'show_on_front' ) ) {
		return ! bigbang_edited_with_pagebuilder();
	}
	return false;
}
