<?php
/**
 * Customizer functionality for the Slider section.
 *
 * @package bigbang
 * @since bigbang 1.0
 */

/**
 * Hook controls for Slider section to Customizer.
 *
 * @since bigbang 1.0
 * @modified 1.1.30
 */

/**
 * Add controls for second button in Big Title Section
 * Compatibility with orfeo child theme
 *
 * @return array - new args for radio image control
 * package bigbang
 * since 1.1.74
 */
function bigbang_add_orfeo_button_controls( $args ) {

	array_push( $args['choices']['slider']['controls'], 'orfeo_big_title_second_button_text', 'orfeo_big_title_second_button_link' );

	return $args;
}
if ( defined( 'ORFEO_VERSION' ) ) {

	add_filter( 'bigbang_slider_tabs_filter_args', 'bigbang_add_orfeo_button_controls' );
}

/**
 * Add selective refresh for big title section controls.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 * @since 1.1.31
 * @access public
 */
function bigbang_register_big_title_partials( $wp_customize ) {
	$wp_customize->selective_refresh->add_partial(
		'bigbang_big_title_title', array(
			'selector'        => '.carousel .bigbang-title',
			'settings'        => 'bigbang_big_title_title',
			'render_callback' => 'bigbang_big_title_title_render_callback',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'bigbang_big_title_text', array(
			'selector'        => '.carousel .sub-title',
			'settings'        => 'bigbang_big_title_text',
			'render_callback' => 'bigbang_big_title_text_render_callback',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'bigbang_big_title_button', array(
			'selector'        => '.carousel .buttons',
			'settings'        => array( 'bigbang_big_title_button_text', 'bigbang_big_title_button_link' ),
			'render_callback' => 'bigbang_big_title_button_render_callback',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'bigbang_big_title_background', array(
			'selector'        => '.big-title-image',
			'settings'        => 'bigbang_big_title_background',
			'render_callback' => 'bigbang_big_title_image_callback',
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'bigbang_slider_alignment', array(
			'selector'        => '.bigbang-big-title-content',
			'settings'        => 'bigbang_slider_alignment',
			'render_callback' => 'bigbang_slider_alignment_callback',
		)
	);
}
add_action( 'customize_register', 'bigbang_register_big_title_partials' );

/**
 * Render callback function for header title selective refresh
 *
 * @return string
 */
function bigbang_big_title_title_render_callback() {
	return get_theme_mod( 'bigbang_big_title_title' );
}

/**
 * Render callback function for header subtitle selective refresh
 *
 * @return string
 */
function bigbang_big_title_text_render_callback() {
	return get_theme_mod( 'bigbang_big_title_text' );
}

/**
 * Render callback function for slider alignment selective refresh
 *
 * @since 1.1.41
 */
function bigbang_slider_alignment_callback() {
	$section_content = bigbang_get_big_title_content();
	bigbang_show_big_title_content( $section_content );
}

/**
 * Render callback function for header button selective refresh
 *
 * @return string
 */
function bigbang_big_title_button_render_callback() {
	$button_text = get_theme_mod( 'bigbang_big_title_button_text' );
	$button_link = get_theme_mod( 'bigbang_big_title_button_link' );

	$output = '';

	if ( ! empty( $button_text ) && ! empty( $button_link ) ) {
		$output = '<a href="' . $button_link . '" title="' . $button_text . '" class="btn btn-primary btn-lg">' . $button_text . '</a>';
	}

	return wp_kses_post( $output );
}

/**
 * Callback function for big title background selective refresh.
 *
 * @since 1.1.31
 * @access public
 */
function bigbang_big_title_image_callback() {
	$bigbang_parallax_layer1 = get_theme_mod( 'bigbang_parallax_layer1' );
	$bigbang_parallax_layer2 = get_theme_mod( 'bigbang_parallax_layer2' );
	if ( empty( $bigbang_parallax_layer1 ) || empty( $bigbang_parallax_layer2 ) ) {
		$bigbang_big_title_background = get_theme_mod( 'bigbang_big_title_background' );
		?>
		<style class="big-title-image-css">
			#carousel-bigbang-generic .header-filter {
				<?php
				if ( ! empty( $bigbang_big_title_background ) ) {
					echo 'background-image: url(' . esc_url( $bigbang_big_title_background ) . ') !important;';
				} else {
					echo 'background-image: none !important;';
				}
				?>
			}
		</style>
		<?php
	}
}
