<?php
/**
 * Customizer functionality for the Blog settings panel from both lite and pro versions.
 *
 * @package bigbang
 * @since bigbang 1.1.1
 */


/**
 * Add blog settings in both lite and pro versions of the theme.
 *
 * @param object $wp_customize Customize manager object.
 * @since 1.1.1
 */
function bigbang_blog_settings_lite_customize_register( $wp_customize ) {

	$wp_customize->add_section(
		'bigbang_blog_layout', array(
			'title'    => apply_filters( 'bigbang_blog_layout_control_label', esc_html__( 'Blog Settings', 'bigbang' ) ),
			'priority' => 30,
		)
	);

		$options    = array( 0 => ' -- ' . esc_html__( 'Disable section', 'bigbang' ) . ' -- ' );
		$categories = get_categories();
	if ( ! empty( $categories ) ) {
		foreach ( $categories as $category ) {
			$cat_id             = $category->term_id;
			$cat_name           = $category->name;
			$options[ $cat_id ] = $cat_name;
		}
	}

		$wp_customize->add_setting(
			'bigbang_featured_posts_category', array(
				'sanitize_callback' => 'bigbang_sanitize_array',
				'default'           => apply_filters( 'bigbang_featured_posts_category_default', 0 ),
			)
		);

		$wp_customize->add_control(
			'bigbang_featured_posts_category', array(
				'type'     => 'select',
				'section'  => 'bigbang_blog_layout',
				'label'    => esc_html__( 'Featured Posts', 'bigbang' ),
				'choices'  => $options,
				'priority' => 10,
			)
		);

}
add_action( 'customize_register', 'bigbang_blog_settings_lite_customize_register' );
