<?php
/**
 * Customizer functionality for the Contact section.
 *
 * @package bigbang
 * @since bigbang 1.1.51
 */

/**
 * Hook controls for Contact form shortcode control to Customizer.
 *
 * @since bigbang 1.1.51
 */
function bigbang_contact_form_shortcode_customize_register( $wp_customize ) {

	$selective_refresh = isset( $wp_customize->selective_refresh ) ? 'postMessage' : 'refresh';

	$wp_customize->add_setting(
		'bigbang_contact_form_shortcode', array(
			'default'           => esc_html__( '[pirate_forms]', 'bigbang' ),
			'sanitize_callback' => 'sanitize_text_field',
			'transport'         => $selective_refresh,
		)
	);

	$wp_customize->add_control(
		'bigbang_contact_form_shortcode', array(
			'label'    => esc_html__( 'Shortcode', 'bigbang' ),
			'section'  => 'bigbang_contact',
			'priority' => 26,
		)
	);
}
add_action( 'customize_register', 'bigbang_contact_form_shortcode_customize_register' );

/**
 * Add selective refresh for contact form.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 * @since 1.1.51
 * @access public
 */
function bigbang_register_contact_form_partials( $wp_customize ) {

	// Abort if selective refresh is not available.
	if ( ! isset( $wp_customize->selective_refresh ) ) {
		return;
	}

	$wp_customize->selective_refresh->add_partial(
		'bigbang_contact_form_shortcode', array(
			'selector'        => '.contactus .card-contact .content',
			'settings'        => 'bigbang_contact_form_shortcode',
			'render_callback' => 'bigbang_contact_form_callback',
		)
	);
}
add_action( 'customize_register', 'bigbang_register_contact_form_partials' );

/**
 * Render callback function for contact form selective refresh
 *
 * @since 1.1.51
 * @access public
 * @return void
 */
function bigbang_contact_form_callback() {

	$bigbang_contact_form_shortcode_default = '[pirate_forms]';
	$bigbang_contact_form_shortcode         = get_theme_mod( 'bigbang_contact_form_shortcode', $bigbang_contact_form_shortcode_default );

	if ( $bigbang_contact_form_shortcode === $bigbang_contact_form_shortcode_default || empty( $bigbang_contact_form_shortcode ) ) {
		echo do_shortcode( '[pirate_forms]' );
	} else {
		echo do_shortcode( wp_kses_post( $bigbang_contact_form_shortcode ) );
	}
}
