<?php
/**
 * Tabs test file
 *
 * @package bigbang
 * @since 1.1.1
 */

/**
 * Hook controls for Header to Customizer.
 *
 * @since 1.1.1
 */
function bigbang_tabs_customize_register( $wp_customize ) {

	if ( class_exists( 'bigbang_Customize_Control_Tabs' ) ) {

		// Typography Tabs
		$wp_customize->add_setting(
			'bigbang_typography_tabs', array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			new bigbang_Customize_Control_Tabs(
				$wp_customize, 'bigbang_typography_tabs', array(
					'section' => 'bigbang_typography',
					'tabs'    => array(
						'font_family' => array(
							'nicename' => esc_html__( 'font family', 'bigbang' ),
							'icon'     => 'font',
							'controls' => array(
								'bigbang_headings_font',
								'bigbang_body_font',
								'bigbang_font_subsets',
							),
						),
						'font_sizes'  => array(
							'nicename' => esc_html__( 'font size', 'bigbang' ),
							'icon'     => 'text-height',
							'controls' => array(
								'bigbang_posts_and_pages_title',
								'bigbang_header_titles_fs',
								'bigbang_post_page_headings_fs',
								'bigbang_post_page_content_fs',

								'bigbang_frontpage_sections_title',
								'bigbang_big_title_fs',
								'bigbang_section_primary_headings_fs',
								'bigbang_section_secondary_headings_fs',
								'bigbang_section_content_fs',

								'bigbang_generic_title',
								'bigbang_menu_fs',
							),
						),
					),
				)
			)
		);

		// Very Top Bar Tabs
		$wp_customize->add_setting(
			'bigbang_very_top_bar_tabs', array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			new bigbang_Customize_Control_Tabs(
				$wp_customize, 'bigbang_very_top_bar_tabs', array(
					'section' => 'bigbang_top_bar',
					'tabs'    => array(
						'general'    => array(
							'nicename' => esc_html__( 'General Settings', 'bigbang' ),
							'controls' => array(
								'bigbang_top_bar_hide',
								'bigbang_top_bar_alignment',
								'bigbang_link_to_top_menu',
								'widgets',
							),
						),
						'appearance' => array(
							'nicename' => esc_html__( 'Appearance Settings', 'bigbang' ),
							'controls' => array(
								'bigbang_top_bar_text_color',
								'bigbang_top_bar_link_color',
								'bigbang_top_bar_link_color_hover',
								'bigbang_top_bar_background_color',
							),
						),
					),
				)
			)
		);

		// Subscribe Section Tabs
		$wp_customize->add_setting(
			'bigbang_subscribe_tabs', array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			new bigbang_Customize_Control_Tabs(
				$wp_customize, 'bigbang_subscribe_tabs', array(
					'section' => 'bigbang_subscribe',
					'tabs'    => array(
						'general'    => array(
							'nicename' => esc_html__( 'General Settings', 'bigbang' ),
							'controls' => array(
								'bigbang_subscribe_hide',
								'bigbang_subscribe_background',
								'bigbang_subscribe_title',
								'bigbang_subscribe_subtitle',
								'widgets',
							),
						),
						'sendinblue' => array(
							'nicename' => esc_html__( 'SendinBlue plugin', 'bigbang' ),
							'controls' => array(
								'bigbang_subscribe_info',
							),
						),
					),
				)
			)
		);

		// Contact Section Tabs
		$wp_customize->add_setting(
			'bigbang_contact_tabs', array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			new bigbang_Customize_Control_Tabs(
				$wp_customize, 'bigbang_contact_tabs', array(
					'section' => 'bigbang_contact',
					'tabs'    => array(
						'general' => array(
							'nicename' => esc_html__( 'General Settings', 'bigbang' ),
							'icon'     => 'cogs',
							'controls' => array(
								'bigbang_contact_hide',
								'bigbang_contact_title',
								'bigbang_contact_subtitle',
								'bigbang_contact_background',
								'bigbang_contact_area_title',
							),
						),
						'contact' => array(
							'nicename' => esc_html__( 'Contact Content', 'bigbang' ),
							'icon'     => 'newspaper-o',
							'controls' => array(
								'bigbang_contact_info',
								'bigbang_contact_content_new',
								'bigbang_contact_form_shortcode',
							),
						),
					),
				)
			)
		);

		// Shop Section Tabs
		$wp_customize->add_setting(
			'bigbang_shop_tabs', array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			new bigbang_Customize_Control_Tabs(
				$wp_customize, 'bigbang_shop_tabs', array(
					'section' => 'bigbang_shop',
					'tabs'    => array(
						'general' => array(
							'nicename' => esc_html__( 'General Settings', 'bigbang' ),
							'icon'     => 'cogs',
							'controls' => array(
								'bigbang_shop_hide',
								'bigbang_shop_title',
								'bigbang_shop_subtitle',
								'bigbang_shop_items',
								'bigbang_shop_categories',
							),
						),
						'contact' => array(
							'nicename' => esc_html__( 'Products', 'bigbang' ),
							'icon'     => 'gift',
							'controls' => array(
								'bigbang_shop_order',
								'bigbang_shop_shortcode',
							),
						),
					),
				)
			)
		);

		$control_handle = $wp_customize->get_control( 'bigbang_very_top_bar_tabs' );
		if ( ! empty( $control_handle ) ) {
			$control_handle->section  = 'sidebar-widgets-sidebar-top-bar';
			$control_handle->priority = -100;
		}
		$control_handle = $wp_customize->get_control( 'bigbang_subscribe_tabs' );
		if ( ! empty( $control_handle ) ) {
			$control_handle->section  = 'sidebar-widgets-subscribe-widgets';
			$control_handle->priority = -100;
		}
	}

	if ( class_exists( 'bigbang_Customize_Control_Scroll' ) ) {
		$scroller = new bigbang_Customize_Control_Scroll();
	}
}
add_action( 'customize_register', 'bigbang_tabs_customize_register' );
