<?php
/**
 * Customizer functionality for the Theme Info section.
 *
 * @package bigbang
 * @since bigbang 1.0
 */

$theme_info_path = trailingslashit( get_template_directory() ) . 'inc/customizer-theme-info/class-bigbang-customizer-theme-info.php';
if ( file_exists( $theme_info_path ) ) {
	require_once( $theme_info_path );
}

/**
 * Hook controls for Features section to Customizer.
 *
 * @since bigbang 1.0
 */
function bigbang_theme_info_customize_register( $wp_customize ) {

	if ( ! class_exists( 'bigbang_Control_Upsell_Theme_Info' ) ) {
		return;
	}

	$wp_customize->add_section(
		'bigbang_theme_info_main_section', array(
			'title'    => esc_html__( 'View PRO Features', 'bigbang' ),
			'priority' => 0,
		)
	);

	$wp_customize->add_setting(
		'bigbang_theme_info_main_control', array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		new bigbang_Control_Upsell_Theme_Info(
			$wp_customize, 'bigbang_theme_info_main_control', array(
				'section'            => 'bigbang_theme_info_main_section',
				'priority'           => 100,
				'options'            => array(
					esc_html__( 'Header Slider', 'bigbang' ),
					esc_html__( 'Fully Customizable Colors', 'bigbang' ),
					esc_html__( 'Jetpack Portfolio', 'bigbang' ),
					esc_html__( 'Pricing Plans Section', 'bigbang' ),
					esc_html__( 'Section Reordering', 'bigbang' ),
					esc_html__( 'Quality Support', 'bigbang' ),
				),
				'explained_features' => array(
					esc_html__( 'You will be able to add more content to your site header with an awesome slider.', 'bigbang' ),
					esc_html__( 'Change colors for the header overlay, header text and navbar.', 'bigbang' ),
					esc_html__( 'Portfolio section with two possible layouts.', 'bigbang' ),
					esc_html__( 'A fully customizable pricing plans section.', 'bigbang' ),
					esc_html__( 'Drag and drop panels to change the order of sections.', 'bigbang' ),
					esc_html__( 'The ability to reorganize your Frontpage Sections more easily and quickly.', 'bigbang' ),
					esc_html__( '24/7 HelpDesk Professional Support', 'bigbang' ),
				),
				'button_url'         => esc_url( apply_filters( 'bigbang_upgrade_link_from_child_theme_filter', 'https://themetechs.com/themes/bigbang-pro/upgrade/' ) ),
				'button_text'        => esc_html__( 'Get the PRO version!', 'bigbang' ),
			)
		)
	);

}

add_action( 'customize_register', 'bigbang_theme_info_customize_register' );
