<?php
/**
 * Blog section for the homepage.
 *
 * @package bigbang
 * @since bigbang 1.0
 */

if ( ! function_exists( 'bigbang_blog' ) ) :

	/**
	 * Blog section content.
	 * This function can be called from a shortcode too.
	 * When it's called as shortcode, the title and the subtitle shouldn't appear and it should be visible all the time,
	 * it shouldn't matter if is disable on front page.
	 *
	 * @since bigbang 1.0
	 * @modified 1.1.51
	 */
	function bigbang_blog( $is_shortcode = false ) {

		/**
		 * Don't show section if Disable section is checked.
		 * Show it if it's called as a shortcode.
		 */
		$hide_section  = get_theme_mod( 'bigbang_blog_hide', false );
		$section_style = '';
		if ( $is_shortcode === false && (bool) $hide_section === true ) {
			if ( is_customize_preview() ) {
				$section_style = 'style="display: none"';
			} else {
				return;
			}
		}

		/**
		 * Gather data to display the section.
		 */
		if ( current_user_can( 'edit_theme_options' ) ) {
			/* translators: 1 - link to customizer setting. 2 - 'customizer' */
			$bigbang_blog_subtitle = get_theme_mod( 'bigbang_blog_subtitle', sprintf( __( 'Change this subtitle in the %s.', 'bigbang' ), sprintf( '<a href="%1$s" class="default-link">%2$s</a>', esc_url( admin_url( 'customize.php?autofocus&#91;control&#93;=bigbang_blog_subtitle' ) ), __( 'Customizer', 'bigbang' ) ) ) );
		} else {
			$bigbang_blog_subtitle = get_theme_mod( 'bigbang_blog_subtitle' );
		}
		$bigbang_blog_title = get_theme_mod( 'bigbang_blog_title', __( 'Blog', 'bigbang' ) );
		if ( $is_shortcode ) {
			$bigbang_blog_title    = '';
			$bigbang_blog_subtitle = '';
		}

		/**
		 * In case this function is called as shortcode, we remove the container and we add 'is-shortcode' class.
		 */
		$wrapper_class   = $is_shortcode === true ? 'is-shortcode' : '';
		$container_class = $is_shortcode === true ? '' : 'container';

		bigbang_before_blog_section_trigger(); ?>
		<section class="bigbang-blogs <?php echo esc_attr( $wrapper_class ); ?>" id="blog" data-sorder="bigbang_blog" <?php echo wp_kses_post( $section_style ); ?>>
			<?php
			bigbang_before_blog_section_content_trigger();
			if ( $is_shortcode === false ) {
				bigbang_display_customizer_shortcut( 'bigbang_blog_hide', true );
			}
			?>
			<div class="<?php echo esc_attr( $container_class ); ?>">
				<?php
				bigbang_top_blog_section_content_trigger();
				if ( $is_shortcode === false ) {
					?>
					<div class="row">
						<div class="col-md-8 col-md-offset-2 text-center bigbang-blogs-title-area">
							<?php
							bigbang_display_customizer_shortcut( 'bigbang_blog_title' );
							if ( ! empty( $bigbang_blog_title ) || is_customize_preview() ) {
								echo '<h2 class="bigbang-title">' . wp_kses_post( $bigbang_blog_title ) . '</h2>';
							}
							if ( ! empty( $bigbang_blog_subtitle ) || is_customize_preview() ) {
								echo '<h5 class="description">' . bigbang_sanitize_string( $bigbang_blog_subtitle ) . '</h5>';
							}
							?>
						</div>
					</div>
					<?php
				}
				bigbang_blog_content();
				?>
				<?php bigbang_bottom_blog_section_content_trigger(); ?>
			</div>
			<?php bigbang_after_blog_section_content_trigger(); ?>
		</section>
		<?php
		bigbang_after_blog_section_trigger();
	}

endif;

if ( ! function_exists( 'bigbang_blog_content' ) ) {
	/**
	 * Get content for blog section.
	 *
	 * @since 1.1.31
	 * @access public
	 * @param bool $is_callback Flag to check if it's callback or not.
	 */
	function bigbang_blog_content( $is_callback = false ) {

		$bigbang_blog_items = get_theme_mod( 'bigbang_blog_items', 3 );
		if ( ! $is_callback ) {
			?>
			<div class="bigbang-blog-content">
			<?php
		}

		$args                   = array(
			'ignore_sticky_posts' => true,
		);
		$args['posts_per_page'] = ! empty( $bigbang_blog_items ) ? absint( $bigbang_blog_items ) : 3;

		$bigbang_blog_categories = get_theme_mod( 'bigbang_blog_categories' );

		if ( ! empty( $bigbang_blog_categories[0] ) && sizeof( $bigbang_blog_categories ) >= 1 ) {
			$args['tax_query'] = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'term_id',
					'terms'    => $bigbang_blog_categories,
				),
			);
		}

		$loop = new WP_Query( $args );

		$allowed_html = array(
			'br'     => array(),
			'em'     => array(),
			'strong' => array(),
			'i'      => array(
				'class' => array(),
			),
			'span'   => array(),
		);

		if ( $loop->have_posts() ) :
			$i = 1;
			echo '<div class="row" ' . bigbang_add_animationation( 'fade-up' ) . '>';
			while ( $loop->have_posts() ) :
				$loop->the_post();
				?>
				<article class="col-xs-12 col-ms-10 col-ms-offset-1 col-sm-8 col-sm-offset-2 <?php echo apply_filters( 'bigbang_blog_per_row_class', 'col-md-4' ); ?> bigbang-blog-item">
					<div class="card card-plain card-blog">
						<?php if ( has_post_thumbnail() ) : ?>
							<div class="card-image">
								<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
									<?php the_post_thumbnail( 'bigbang-blog' ); ?>
								</a>
							</div>
						<?php endif; ?>
						<div class="content">
							<h6 class="category"><?php bigbang_category(); ?></h6>
							<h4 class="card-title">
								<a class="blog-item-title-link" href="<?php echo esc_url( get_permalink() ); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark">
									<?php echo wp_kses( force_balance_tags( get_the_title() ), $allowed_html ); ?>
								</a>
							</h4>
							<p class="card-description"><?php echo wp_kses_post( get_the_excerpt() ); ?></p>
						</div>
					</div>
				</article>
				<?php
				if ( $i % apply_filters( 'bigbang_blog_per_row_no', 3 ) == 0 ) {
					echo '</div><!-- /.row -->';
					echo '<div class="row" ' . bigbang_add_animationation( 'fade-up' ) . '>';
				}
				$i++;
			endwhile;
			echo '</div>';

			wp_reset_postdata();
		endif;

		if ( ! $is_callback ) {
			?>
			</div>
			<?php
		}
	}
}

if ( function_exists( 'bigbang_blog' ) ) {
	$section_priority = apply_filters( 'bigbang_section_priority', 60, 'bigbang_blog' );
	add_action( 'bigbang_sections', 'bigbang_blog', absint( $section_priority ), 2 );
}
